==> pyrotgfork-2.1.33.10-py3-none-any.whl: pyrogram/raw/base/broadcast_revenue_transaction.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

BroadcastRevenueTransaction = Union[raw.types.BroadcastRevenueTransactionProceeds, raw.types.BroadcastRevenueTransactionRefund, raw.types.BroadcastRevenueTransactionWithdrawal]


# noinspection PyRedeclaration
class BroadcastRevenueTransaction:  # type: ignore
    """A channel ad revenue » transaction.

    Constructors:
        This base type has 3 constructors available.

        .. currentmodule:: pyrogram.raw.types

        .. autosummary::
            :nosignatures:

            BroadcastRevenueTransactionProceeds
            BroadcastRevenueTransactionRefund
            BroadcastRevenueTransactionWithdrawal
    """

    QUALNAME = "pyrogram.raw.base.BroadcastRevenueTransaction"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes: "
                        "you tried to use a base type instance as argument, "
                        "but you need to instantiate one of its constructors instead. "
                        "More info: https://docs.pyrogram.org/telegram/base/broadcast-revenue-transaction")

==> pyrotgfork-2.2.12-py3-none-any.whl: pyrogram/raw/base/broadcast_revenue_transaction.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

BroadcastRevenueTransaction = Union[raw.types.BroadcastRevenueTransactionProceeds, raw.types.BroadcastRevenueTransactionRefund, raw.types.BroadcastRevenueTransactionWithdrawal]


# noinspection PyRedeclaration
class BroadcastRevenueTransaction:  # type: ignore
    """A channel ad revenue » transaction.

    Constructors:
        This base type has 3 constructors available.

        .. currentmodule:: pyrogram.raw.types

        .. autosummary::
            :nosignatures:

            BroadcastRevenueTransactionProceeds
            BroadcastRevenueTransactionRefund
            BroadcastRevenueTransactionWithdrawal
    """

    QUALNAME = "pyrogram.raw.base.BroadcastRevenueTransaction"

    def __init__(self):
        raise TypeError(
            "Base types can only be used for type checking purposes: "
            "you tried to use a base type instance as argument, "
            "but you need to instantiate one of its constructors instead. "
            "More info: https://telegramplayground.github.io/pyrogram/telegram/base/broadcast-revenue-transaction"
        )
